==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-impl/src/main/java/org/apache/webbeans/portable/ExtensionProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.portable;

import java.util.Map;

import javax.enterprise.inject.spi.AnnotatedType;
import javax.enterprise.inject.spi.Bean;
import javax.enterprise.inject.spi.Interceptor;

import org.apache.webbeans.config.WebBeansContext;
import org.apache.webbeans.context.creational.CreationalContextImpl;
import org.apache.webbeans.portable.events.ExtensionLoader;

public class ExtensionProducer<R> extends AbstractProducer<R>
{

    private WebBeansContext webBeansContext;
    public <T> ExtensionProducer(AnnotatedType<T> annotatedType,
                                 Bean<T> owner,
                                 WebBeansContext webBeansContext)
    {
        super(webBeansContext.getInjectionPointFactory().buildInjectionPoints(owner, annotatedType));
        this.webBeansContext = webBeansContext; 
    }

    @Override
    protected R produce(Map<Interceptor<?>, ?> interceptors, CreationalContextImpl<R> creationalContext)
    {
        ExtensionLoader loader = webBeansContext.getExtensionLoader();
        
        return loader.getBeanInstance((Bean<R>)((CreationalContextImpl<R>) creationalContext).getBean());
    }
}

==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/main/java/org/apache/webbeans/portable/ExtensionProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.portable;

import java.util.Map;

import javax.enterprise.inject.spi.AnnotatedType;
import javax.enterprise.inject.spi.Bean;
import javax.enterprise.inject.spi.Interceptor;

import org.apache.webbeans.config.WebBeansContext;
import org.apache.webbeans.context.creational.CreationalContextImpl;
import org.apache.webbeans.portable.events.ExtensionLoader;

public class ExtensionProducer<R> extends AbstractProducer<R>
{

    private WebBeansContext webBeansContext;
    public <T> ExtensionProducer(AnnotatedType<T> annotatedType,
                                 Bean<T> owner,
                                 WebBeansContext webBeansContext)
    {
        super(webBeansContext.getInjectionPointFactory().buildInjectionPoints(owner, annotatedType));
        this.webBeansContext = webBeansContext; 
    }

    @Override
    protected R produce(Map<Interceptor<?>, ?> interceptors, CreationalContextImpl<R> creationalContext)
    {
        ExtensionLoader loader = webBeansContext.getExtensionLoader();
        
        return (R) loader.getExtension(creationalContext.getBean().getBeanClass());
    }
}
